#!/bin/bash
#
# Find files common between a certain transcript and other transcripts
#
# wmertens@cisco.com

export PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin

help () {
	echo "Usage: $0 [-K commandfile] [-T transcriptdir] transcript"
	exit 1
}

[ $# -lt 1 ] && help

KFILE=/var/radmind/client/command.K
TRANSD=/var/radmind/client/
while getopts ':K:T:' OPT; do
	case $OPT in
		K) KFILE="$OPTARG" ;;
		T) TRANSD="$OPTARG" ;;
		*) help ;;
	esac
done
shift $(( OPTIND - 1 ))
TRANSCRIPT="$1"
TRANSNAME="`basename "$1"`"

die(){
	echo "$*"
	exit 1
}

T=/tmp/find_common.$$

# First generate a list of all files
awk '$1~/[+-*]/{n=3}$1~/[hldcbpsDfam]/{n=2}n!=0{print " " $n " ";print " " $n "\t"; n=0}' "$TRANSCRIPT" > $T
if [ ! -s "$T" ]; then
	rm "$T"
	die "$TRANSCRIPT: not a transcript? (no files)"
fi

get_transcripts() {
	kname="`basename "$1"`"
	awk '$1~/^[knp]$/{print $0}' "$1" | while read type file; do
		case $type in
			p)	echo "$file" ;;
			n)	echo "$file" ;;
			k)	get_transcripts "`dirname "$1"`/$file" ;;
		esac
	done
}

for i in `get_transcripts "$KFILE"`; do
	if [ "$i" != "$TRANSNAME" ]; then
		grep -Ff "$T" "$TRANSD/$i" | sed "s/^/$i	/"
	else
		echo "=== $i ==="
	fi
done
rm "$T"
